@@ -52,7 +52,10 @@ from alfasim_sdk._internal.alfacase.case_description import (
 )
 from alfasim_sdk._internal.alfacase.case_description import EquipmentDescription
 from alfasim_sdk._internal.alfacase.case_description import AnnulusEquipmentDescription
-from alfasim_sdk._internal.alfacase.case_description import FluidDescription
+from alfasim_sdk._internal.alfacase.case_description import CombinedFluidDescription
+from alfasim_sdk._internal.alfacase.case_description import (
+    CompositionalFluidDescription,
+)
 from alfasim_sdk._internal.alfacase.case_description import FormationDescription
 from alfasim_sdk._internal.alfacase.case_description import FormationLayerDescription
 from alfasim_sdk._internal.alfacase.case_description import (
@@ -120,6 +123,9 @@ from alfasim_sdk._internal.alfacase.case_description import PumpEquipmentDescrip
 from alfasim_sdk._internal.alfacase.case_description import (
     PvtModelCompositionalDescription,
 )
+from alfasim_sdk._internal.alfacase.case_description import (
+    PvtModelCombinedDescription,
+)
 from alfasim_sdk._internal.alfacase.case_description import (
     PvtModelCorrelationDescription,
 )
@@ -172,6 +178,7 @@ from alfasim_sdk._internal.alfacase.case_description import (
     GlobalTrendDescription,
     EquipmentTrendDescription,
     SeparatorTrendDescription,
+    ControllerTrendDescription,
 )
 from alfasim_sdk._internal.alfacase.case_description import TubingDescription
 from alfasim_sdk._internal.alfacase.case_description import ValveEquipmentDescription
@@ -213,13 +220,18 @@ from alfasim_sdk._internal.constants import DEFAULT_TEMPERATURE_IN_K
 from alfasim_sdk._internal.constants import DrainageRateMode
 from alfasim_sdk._internal.constants import DROPLET_FIELD
 from alfasim_sdk._internal.constants import EmulsionModelType
+from alfasim_sdk._internal.constants import EmulsionRelativeViscosityModelType
+from alfasim_sdk._internal.constants import EmulsionDropletSizeModelType
+from alfasim_sdk._internal.constants import EmulsionInversionPointModelType
 from alfasim_sdk._internal.constants import EnergyModel
 from alfasim_sdk._internal.constants import EnergyModelPrimaryVariable
 from alfasim_sdk._internal.constants import EquationOfStateType
+from alfasim_sdk._internal.constants import EquipmentAttachmentLocation
 from alfasim_sdk._internal.constants import EvaluationStrategyType
 from alfasim_sdk._internal.constants import EXTRAS_REQUIRED_VERSION_KEY
 from alfasim_sdk._internal.constants import FlashModel
 from alfasim_sdk._internal.constants import FlowDirection
+from alfasim_sdk._internal.constants import FlowPatternModel
 from alfasim_sdk._internal.constants import FLUID_GAS
 from alfasim_sdk._internal.constants import FLUID_OIL
 from alfasim_sdk._internal.constants import FLUID_PHASE_NAMES
@@ -232,7 +244,6 @@ from alfasim_sdk._internal.constants import HydrodynamicModelType
 from alfasim_sdk._internal.constants import InitialConditionStrategyType
 from alfasim_sdk._internal.constants import InterpolationType
 from alfasim_sdk._internal.constants import LeakLocation
-from alfasim_sdk._internal.constants import EquipmentAttachmentLocation
 from alfasim_sdk._internal.constants import LeakModel
 from alfasim_sdk._internal.constants import LeakType
 from alfasim_sdk._internal.constants import MassInflowSplitType
@@ -245,7 +256,6 @@ from alfasim_sdk._internal.constants import OIL_FIELD
 from alfasim_sdk._internal.constants import OIL_LAYER
 from alfasim_sdk._internal.constants import OIL_PHASE
 from alfasim_sdk._internal.constants import OutputAttachmentLocation
-from alfasim_sdk._internal.constants import PVTCompositionalViscosityModel
 from alfasim_sdk._internal.constants import PigRoutingMode
 from alfasim_sdk._internal.constants import PigTrappingMode
 from alfasim_sdk._internal.constants import (
@@ -254,6 +264,7 @@ from alfasim_sdk._internal.constants import (
 from alfasim_sdk._internal.constants import PipeThermalModelType
 from alfasim_sdk._internal.constants import PipeThermalPositionInput
 from alfasim_sdk._internal.constants import PumpType
+from alfasim_sdk._internal.constants import PVTCompositionalViscosityModel
 from alfasim_sdk._internal.constants import SeparatorGeometryType
 from alfasim_sdk._internal.constants import SimulationModeType
 from alfasim_sdk._internal.constants import SimulationRegimeType
@@ -271,6 +282,9 @@ from alfasim_sdk._internal.constants import WATER_LAYER
 from alfasim_sdk._internal.constants import WATER_PHASE
 from alfasim_sdk._internal.constants import WellConnectionPort
 from alfasim_sdk._internal.constants import WellIndexPhaseType
+from alfasim_sdk._internal.constants import CorrelationsOilViscosity
+from alfasim_sdk._internal.constants import CorrelationsGasViscosity
+from alfasim_sdk._internal.constants import CorrelationsSurfaceTension
 
 # Plugins: Layouts imports
 from alfasim_sdk._internal.layout import tab
@@ -319,9 +333,15 @@ from alfasim_sdk._internal.variables import Type
 from alfasim_sdk._internal.variables import Location
 
 __all__ = [
-    "console_main",
+    "AddField",
+    "AddLayer",
+    "AddPhase",
     "AnnulusDescription",
+    "AnnulusEquipmentDescription",
+    "BUBBLE_FIELD",
+    "BaseField",
     "BipDescription",
+    "Boolean",
     "CaseDescription",
     "CaseOutputDescription",
     "CasingDescription",
@@ -329,23 +349,61 @@ __all__ = [
     "CompositionDescription",
     "CompressorEquipmentDescription",
     "CompressorPressureTableDescription",
-    "ControllerNodePropertiesDescription",
+    "CompressorSpeedType",
     "ControllerInputSignalPropertiesDescription",
+    "ControllerNodePropertiesDescription",
     "ControllerOutputSignalPropertiesDescription",
+    "ControllerTrendDescription",
     "ControllerType",
+    "CorrelationPackage",
+    "CorrelationPackageType",
+    "CorrelationsOilViscosity",
+    "CorrelationsGasViscosity",
+    "CorrelationsSurfaceTension",
     "CvTableDescription",
+    "DEFAULT_TEMPERATURE_IN_K",
+    "DROPLET_FIELD",
+    "DrainageRateMode",
+    "EXTRAS_REQUIRED_VERSION_KEY",
+    "EmulsionModelType",
+    "EmulsionRelativeViscosityModelType",
+    "EmulsionDropletSizeModelType",
+    "EmulsionInversionPointModelType",
+    "EnergyModel",
+    "EnergyModelPrimaryVariable",
+    "Enum",
     "EnvironmentDescription",
     "EnvironmentPropertyDescription",
+    "EquationOfStateType",
+    "EquipmentAttachmentLocation",
     "EquipmentDescription",
-    "AnnulusEquipmentDescription",
-    "FluidDescription",
+    "EquipmentTrendDescription",
+    "ErrorMessage",
+    "EvaluationStrategyType",
+    "FLUID_GAS",
+    "FLUID_OIL",
+    "FLUID_PHASE_NAMES",
+    "FLUID_WATER",
+    "FileContent",
+    "FlashModel",
+    "FlowDirection",
+    "FlowPatternModel",
+    "CompositionalFluidDescription",
+    "CombinedFluidDescription",
     "FormationDescription",
     "FormationLayerDescription",
+    "GAS_FIELD",
+    "GAS_LAYER",
+    "GAS_PHASE",
     "GasLiftValveEquipmentDescription",
+    "GasLiftValveOpeningType",
+    "GlobalTrendDescription",
     "HeatSourceEquipmentDescription",
     "HeavyComponentDescription",
+    "HydrodynamicModelType",
     "IPRCurveDescription",
     "IPRModelsDescription",
+    "InitialConditionStrategyType",
     "InitialConditionsDescription",
     "InitialPressuresDescription",
     "InitialTemperaturesDescription",
@@ -353,156 +411,122 @@ __all__ = [
     "InitialVelocitiesDescription",
     "InitialVolumeFractionsDescription",
     "InternalNodePropertiesDescription",
-    "LengthAndElevationDescription",
+    "InterpolationType",
     "LeakEquipmentDescription",
     "LeakLocation",
-    "EquipmentAttachmentLocation",
+    "LeakModel",
+    "LeakType",
+    "LengthAndElevationDescription",
     "LightComponentDescription",
     "LinearIPRDescription",
+    "Location",
+    "MassInflowSplitType",
     "MassSourceEquipmentDescription",
     "MassSourceNodePropertiesDescription",
+    "MassSourceType",
     "MaterialDescription",
+    "MaterialType",
+    "MultiInputType",
+    "MultipleReference",
+    "NodeCellType",
     "NodeDescription",
+    "NonlinearSolverType",
     "NumericalOptionsDescription",
+    "OIL_FIELD",
+    "OIL_LAYER",
+    "OIL_PHASE",
     "OpenHoleDescription",
+    "OutputAttachmentLocation",
+    "OverallPipeTrendDescription",
+    "PVTCompositionalViscosityModel",
     "PackerDescription",
     "PhysicsDescription",
     "PigEquipmentDescription",
     "PigRoutingMode",
     "PigTrappingMode",
     "PipeDescription",
+    "PipeEnvironmentHeatTransferCoefficientModelType",
     "PipeSegmentsDescription",
+    "PipeThermalModelType",
+    "PipeThermalPositionInput",
+    "PositionalPipeTrendDescription",
     "PressureContainerDescription",
     "PressureNodePropertiesDescription",
     "ProfileDescription",
     "ProfileOutputDescription",
     "PumpEquipmentDescription",
+    "PumpType",
+    "PvtModelCombinedDescription",
     "PvtModelCompositionalDescription",
     "PvtModelCorrelationDescription",
-    "PvtModelsDescription",
     "PvtModelTableParametersDescription",
+    "PvtModelsDescription",
+    "Quantity",
+    "Reference",
     "ReferencedPressureContainerDescription",
     "ReferencedTemperaturesContainerDescription",
     "ReferencedTracersMassFractionsContainerDescription",
     "ReferencedVelocitiesContainerDescription",
     "ReferencedVolumeFractionsContainerDescription",
     "ReservoirInflowEquipmentDescription",
+    "SOLID_PHASE",
+    "Scope",
+    "SecondaryVariable",
+    "SeparatorGeometryType",
     "SeparatorNodePropertiesDescription",
+    "SeparatorTrendDescription",
+    "SimulationModeType",
+    "SimulationRegimeType",
+    "SolidsModelType",
     "SpeedCurveDescription",
+    "String",
+    "SurfaceTensionType",
     "SurgeVolumeOptionsDescription",
+    "SurgeVolumeTimeMode",
+    "Table",
+    "TableColumn",
     "TableIPRDescription",
+    "TableInputType",
     "TablePumpDescription",
     "TemperaturesContainerDescription",
     "TimeOptionsDescription",
     "TracerModelConstantCoefficientsDescription",
+    "TracerModelType",
+    "TracerType",
     "TracersDescription",
     "TracersMassFractionsContainerDescription",
     "TrendsOutputDescription",
-    "PositionalPipeTrendDescription",
-    "OverallPipeTrendDescription",
-    "GlobalTrendDescription",
-    "EquipmentTrendDescription",
-    "SeparatorTrendDescription",
     "TubingDescription",
+    "Type",
+    "UpdateLayer",
+    "UpdatePhase",
     "ValveEquipmentDescription",
-    "VelocitiesContainerDescription",
-    "VolumeFractionsContainerDescription",
-    "WallDescription",
-    "WallLayerDescription",
-    "WellDescription",
-    "XAndYDescription",
-    "convert_alfacase_to_description",
-    "convert_description_to_alfacase",
-    "generate_alfacase_file",
-    "generate_alfatable_file",
-    "load_pvt_model_table_parameters_description_from_alfatable",
-    "BUBBLE_FIELD",
-    "CompressorSpeedType",
-    "CorrelationPackage",
-    "CorrelationPackageType",
-    "DEFAULT_TEMPERATURE_IN_K",
-    "DrainageRateMode",
-    "DROPLET_FIELD",
-    "EXTRAS_REQUIRED_VERSION_KEY",
-    "EmulsionModelType",
-    "EnergyModel",
-    "EnergyModelPrimaryVariable",
-    "EquationOfStateType",
-    "EvaluationStrategyType",
-    "FLUID_GAS",
-    "FLUID_OIL",
-    "FLUID_PHASE_NAMES",
-    "FLUID_WATER",
-    "FlashModel",
-    "FlowDirection",
-    "GAS_FIELD",
-    "GAS_LAYER",
-    "GAS_PHASE",
-    "GasLiftValveOpeningType",
-    "get_metadata",
-    "HydrodynamicModelType",
-    "InitialConditionStrategyType",
-    "InterpolationType",
-    "LeakModel",
-    "LeakType",
-    "MassInflowSplitType",
-    "MassSourceType",
-    "MaterialType",
-    "NodeCellType",
-    "NonlinearSolverType",
-    "OIL_FIELD",
-    "OIL_LAYER",
-    "OIL_PHASE",
-    "OutputAttachmentLocation",
-    "PVTCompositionalViscosityModel",
-    "PipeEnvironmentHeatTransferCoefficientModelType",
-    "PipeThermalModelType",
-    "PipeThermalPositionInput",
-    "MultiInputType",
-    "PumpType",
-    "SOLID_PHASE",
-    "SeparatorGeometryType",
-    "SimulationModeType",
-    "SimulationRegimeType",
-    "SolidsModelType",
-    "SurfaceTensionType",
-    "SurgeVolumeTimeMode",
-    "TableInputType",
-    "TracerModelType",
     "ValveOpeningType",
     "ValveType",
+    "VelocitiesContainerDescription",
+    "Visibility",
+    "VolumeFractionsContainerDescription",
     "WATER_DROPLET_IN_OIL_FIELD",
     "WATER_FIELD",
     "WATER_LAYER",
     "WATER_PHASE",
+    "WallDescription",
+    "WallLayerDescription",
+    "WarningMessage",
     "WellConnectionPort",
+    "WellDescription",
     "WellIndexPhaseType",
+    "XAndYDescription",
+    "console_main",
+    "container_model",
+    "convert_alfacase_to_description",
+    "convert_description_to_alfacase",
+    "data_model",
+    "generate_alfacase_file",
+    "generate_alfatable_file",
+    "get_metadata",
+    "group",
+    "load_pvt_model_table_parameters_description_from_alfatable",
     "tab",
     "tabs",
-    "group",
-    "container_model",
-    "data_model",
-    "WarningMessage",
-    "ErrorMessage",
-    "AddField",
-    "AddPhase",
-    "UpdatePhase",
-    "AddLayer",
-    "UpdateLayer",
-    "Boolean",
-    "Enum",
-    "FileContent",
-    "MultipleReference",
-    "BaseField",
-    "Quantity",
-    "Reference",
-    "String",
-    "Table",
-    "TableColumn",
-    "TracerType",
-    "SecondaryVariable",
-    "Visibility",
-    "Scope",
-    "Type",
-    "Location",
 ]
