@@ -119,11 +119,33 @@ def update_multi_input_flags(document: DescriptionDocument, item_description: T)
     return item_description
 
 
-def load_instance(alfacase_content: DescriptionDocument, class_: Type[T]) -> T:
+@lru_cache(maxsize=None)
+def get_instance_list_loader(*, class_: type) -> Callable:
+    return partial(load_list_of_instance, class_=class_)
+
+
+def load_list_of_instance(
+    alfacase_content: DescriptionDocument, class_: Type[T]
+) -> List[T]:
+    return [
+        load_instance(
+            DescriptionDocument(value, alfacase_content.file_path), class_=class_
+        )
+        for value in alfacase_content.content
+    ]
+
+
+def load_instance(
+    alfacase_content: DescriptionDocument,
+    class_: Type[T],
+    explicit_loaders: Optional[Dict[str, Callable]] = None,
+) -> T:
     """
     Create an instance of class_ with the attributes found in alfacase_content.
     """
-    alfacase_to_case_description = get_case_description_attribute_loader_dict(class_)
+    alfacase_to_case_description = get_case_description_attribute_loader_dict(
+        class_, explicit_loaders=explicit_loaders
+    )
     case_values = to_case_values(alfacase_content, alfacase_to_case_description)
     item_description = class_(**case_values)
     return update_multi_input_flags(alfacase_content, item_description)
@@ -300,7 +322,12 @@ def get_dict_of_arrays_loader(
     )
 
 
-def load_curve(key: str, alfacase_content: DescriptionDocument, category: str) -> Curve:
+def load_curve(
+    key: str,
+    alfacase_content: DescriptionDocument,
+    category: str,
+    domain_category: str = "time",
+) -> Curve:
     """
     Create a barril.curve.curve.Curve instance from the given YAML content.
     # TODO: ASIM-3556: All atributes from this module should get the category from the CaseDescription
@@ -308,13 +335,17 @@ def load_curve(key: str, alfacase_content: DescriptionDocument, category: str) -
     curve_in_alfacase = alfacase_content[key]
     return Curve(
         load_array("image", curve_in_alfacase, category),
-        load_array("domain", curve_in_alfacase, "time"),
+        load_array("domain", curve_in_alfacase, domain_category),
     )
 
 
 @lru_cache(maxsize=None)
 def get_curve_loader(
-    *, category: Optional[str] = None, from_unit: Optional[str] = None
+    *,
+    category: Optional[str] = None,
+    from_unit: Optional[str] = None,
+    domain_category: Optional[str] = None,
+    from_domain_unit: Optional[str] = None,
 ) -> Callable:
     """
     Return a load_curve function pre-populated with the category
@@ -322,8 +353,17 @@ def get_curve_loader(
     If ``from_unit`` is provided, the category parameter will be filled with
     the default category for the given unit.
     """
+    if domain_category is not None or from_domain_unit is not None:
+        return partial(
+            load_curve,
+            category=_obtain_category_for_scalar(category, from_unit),
+            domain_category=_obtain_category_for_scalar(
+                domain_category, from_domain_unit
+            ),
+        )
     return partial(
-        load_curve, category=_obtain_category_for_scalar(category, from_unit)
+        load_curve,
+        category=_obtain_category_for_scalar(category, from_unit),
     )
 
 
@@ -431,6 +471,7 @@ PvtModelTable = str
 PvtModels = Union[
     PvtModelTable,
     case_description.PvtModelCompositionalDescription,
+    case_description.PvtModelCombinedDescription,
     case_description.PvtModelCorrelationDescription,
 ]
 
@@ -595,9 +636,9 @@ def load_composition_description(
     ]
 
 
-def load_fluid_description(
+def load_compositional_fluid_description(
     document: DescriptionDocument,
-) -> Dict[str, case_description.FluidDescription]:
+) -> Dict[str, case_description.CompositionalFluidDescription]:
     alfacase_to_case_description = {
         "composition": load_composition_description,
         "fraction_pairs": load_bip_description,
@@ -605,9 +646,9 @@ def load_fluid_description(
 
     def generate_fluid_description(
         value: DescriptionDocument,
-    ) -> case_description.FluidDescription:
+    ) -> case_description.CompositionalFluidDescription:
         case_values = to_case_values(value, alfacase_to_case_description)
-        item_description = case_description.FluidDescription(**case_values)
+        item_description = case_description.CompositionalFluidDescription(**case_values)
         return update_multi_input_flags(document, item_description)
 
     return {
@@ -633,7 +674,7 @@ def load_pvt_model_compositional_description(
         ),
         "heavy_components": load_heavy_component_description,
         "light_components": load_light_component_description,
-        "fluids": load_fluid_description,
+        "fluids": load_compositional_fluid_description,
     }
 
     def generate_pvt_model_compositional(value: DescriptionDocument):
@@ -651,18 +692,26 @@ def load_pvt_model_compositional_description(
     }
 
 
+def load_combined_fluid_description(
+    document: DescriptionDocument,
+) -> Dict[str, case_description.CombinedFluidDescription]:
+    return load_dict_of_instance(document, case_description.CombinedFluidDescription)
+
+
+def load_pvt_model_combined_description(
+    document: DescriptionDocument,
+) -> Dict[str, case_description.PvtModelCombinedDescription]:
+    return load_dict_of_instance(document, case_description.PvtModelCombinedDescription)
+
+
 def load_pvt_models_description(
     document: DescriptionDocument,
 ) -> case_description.PvtModelsDescription:
-    alfacase_to_case_description = {
-        "default_model": load_value,
-        "tables": load_pvt_tables,
-        "correlations": load_pvt_model_correlation_description,
-        "compositions": load_pvt_model_compositional_description,
-    }
-    case_values = to_case_values(document, alfacase_to_case_description)
-    item_description = case_description.PvtModelsDescription(**case_values)
-    return update_multi_input_flags(document, item_description)
+    return load_instance(
+        document,
+        case_description.PvtModelsDescription,
+        explicit_loaders={"tables": load_pvt_tables},
+    )
 
 
 # Used for testing - Will be ignored on the document contents
@@ -1421,6 +1470,23 @@ def load_separator_trend_description(
     ]
 
 
+def load_controller_trend_description(
+    document: DescriptionDocument,
+) -> List[case_description.ControllerTrendDescription]:
+    alfacase_to_case_description = {
+        "curve_names": load_value,
+        "element_name": load_value,
+    }
+    return [
+        generate_trend_description(
+            alfacase_document,
+            alfacase_to_case_description,
+            case_description.ControllerTrendDescription,
+        )
+        for alfacase_document in document
+    ]
+
+
 def load_global_trend_description(
     document: DescriptionDocument,
 ) -> List[case_description.GlobalTrendDescription]:
@@ -1518,16 +1584,7 @@ def load_annulus_description(
 def load_trends_output_description(
     document: DescriptionDocument,
 ) -> case_description.TrendsOutputDescription:
-    alfacase_to_case_description = {
-        "positional_pipe_trends": load_positional_pipe_trend_description,
-        "equipment_trends": load_equipment_trend_description,
-        "global_trends": load_global_trend_description,
-        "overall_pipe_trends": load_overall_pipe_trend_description,
-        "separator_trends": load_separator_trend_description,
-    }
-    case_values = to_case_values(document, alfacase_to_case_description)
-    item_description = case_description.TrendsOutputDescription(**case_values)
-    return update_multi_input_flags(document, item_description)
+    return load_instance(document, case_description.TrendsOutputDescription)
 
 
 def load_case_output_description(
@@ -1535,8 +1592,10 @@ def load_case_output_description(
 ) -> case_description.CaseOutputDescription:
     alfacase_to_case_description = {
         "profiles": load_profile_output_description,
+        "automatic_profile_frequency": load_value,
         "profile_frequency": get_scalar_loader(from_unit="s"),
         "trends": load_trends_output_description,
+        "automatic_trend_frequency": load_value,
         "trend_frequency": get_scalar_loader(from_unit="s"),
     }
     case_values = to_case_values(document, alfacase_to_case_description)
@@ -1667,33 +1726,6 @@ def _generate_description(
     return update_multi_input_flags(document, item_description)
 
 
-def load_pump_equipment_description(
-    document: DescriptionDocument,
-) -> Dict[str, case_description.PumpEquipmentDescription]:
-    alfacase_to_case_description = {
-        "name": load_value,
-        "position": get_scalar_loader(from_unit="m"),
-        "type": get_enum_loader(enum_class=constants.PumpType),
-        "pressure_boost": get_scalar_loader(from_unit="Pa"),
-        "thermal_efficiency": get_scalar_loader(from_unit="-"),
-        "table": load_table_pump_description,
-        "speed_curve": load_speed_curve_description,
-        "speed_curve_interpolation_type": get_enum_loader(
-            enum_class=constants.InterpolationType
-        ),
-        "flow_direction": get_enum_loader(enum_class=constants.FlowDirection),
-    }
-
-    return {
-        key.data: _generate_description(
-            DescriptionDocument(value, document.file_path),
-            alfacase_to_case_description,
-            case_description.PumpEquipmentDescription,
-        )
-        for key, value in document.content.items()
-    }
-
-
 def load_valve_equipment_description(
     document: DescriptionDocument,
 ) -> Dict[str, case_description.ValveEquipmentDescription]:
@@ -1863,6 +1895,15 @@ def load_physics_description(
         'restart_filepath': load_path,
         'keep_former_results': load_value,
         'emulsion_model': get_enum_loader(enum_class=constants.EmulsionModelType),
+        'emulsion_model_enabled': load_value,
+        'emulsion_relative_viscosity_model': get_enum_loader(enum_class=constants.EmulsionRelativeViscosityModelType),
+        'emulsion_pal_rhodes_phi_rel_100': get_scalar_loader(category='dimensionless'),
+        'emulsion_woelflin_a': get_scalar_loader(category='dimensionless'),
+        'emulsion_woelflin_b': get_scalar_loader(category='dimensionless'),
+        'emulsion_table_based_rel_visc_curve': get_curve_loader(category='dimensionless', domain_category='volume per volume'),
+        'emulsion_relative_viscosity_tuning_factor': get_curve_loader(category='dimensionless', domain_category='volume per volume'),
+        'emulsion_droplet_size_model': get_enum_loader(enum_class=constants.EmulsionDropletSizeModelType),
+        'emulsion_inversion_point_model': get_enum_loader(enum_class=constants.EmulsionInversionPointModelType),
         'emulsion_model_plugin_id': load_value,
         'flash_model': get_enum_loader(enum_class=constants.FlashModel),
         'correlations_package': get_enum_loader(enum_class=constants.CorrelationPackageType),
