@@ -108,6 +108,36 @@ class EmulsionModelType(Enum):
     FromPlugin = "from_plugin"
 
 
+class EmulsionRelativeViscosityModelType(Enum):
+    ModelDefault = "model_default"
+    Taylor1932 = "taylor1932"
+    Brinkman1952 = "brinkman1952"
+    Mooney1951a = "mooney1951a"
+    Mooney1951b = "mooney1951b"
+    PalRhodes1989 = "pal_rhodes1989"
+    Ronningsen1995 = "ronningsen1995"
+    VolumetricWeight = "volumetric_weight"
+    Woelflin1942 = "woelflin_1942"
+    BarneaMizrahi1976 = "barnea_mizrahi1976"
+    TableBased = "table_based"
+    FromPlugin = "from_plugin"
+
+
+class EmulsionDropletSizeModelType(Enum):
+    ModelDefault = "model_default"
+    Hinze1955 = "hinze1955"
+    Sleicher1962 = "sleicher1962"
+    Brauner2001 = "brauner2001"
+    Boxall2012 = "boxall2012"
+
+
+class EmulsionInversionPointModelType(Enum):
+    ModelDefault = "model_default"
+    BraunerUllmann2002 = "brauner_and_ullmann_2002"
+    Brinkman1952AndYeh1964 = "brinkman1952_and_yeh1964"
+    Constant = "constant"
+
+
 class SolidsModelType(Enum):
     """
     Informs which solid model should be used:
@@ -331,6 +361,7 @@ class MultiInputType(Enum):
 class PumpType(Enum):
     ConstantPressure = "constant_pressure"
     TableInterpolation = "table_interpolation"
+    ElectricSubmersiblePump = "electric_submersible_pump"
 
 
 class ValveOpeningType(Enum):
@@ -455,4 +486,25 @@ class PigRoutingMode(Enum):
     UserDefined = "user_defined"
 
 
+class FlowPatternModel(Enum):
+    """
+    Model used for identify the current flow pattern in a given pipe position.
+    """
+
+    UnitCell = "unit_cell"
+    RegimeCapturing = "regime_capturing"
+
+
 MULTI_INPUT_TYPE_SUFFIX = "_input_type"
+
+
+class CorrelationsOilViscosity(Enum):
+    Egbogah = "Egbogah"
+
+
+class CorrelationsGasViscosity(Enum):
+    LeeGonzalezEakin = "Lee Gonzalez Eakin"
+
+
+class CorrelationsSurfaceTension(Enum):
+    BakerSwerdloff = "Baker Swerdloff"
