@@ -81,6 +81,7 @@ typedef int (*get_flow_pattern_func)(
     enum TimestepScope ts_scope,
     int* size
 );
+typedef int (*get_deposition_thickness_func)(void* ctx, double** out, int phase_id, enum TimestepScope ts_scope, int* size);
 typedef int (*get_tracer_id_func)(void* ctx, int* tracer_id, void* reference);
 typedef int (*get_tracer_name_size_func)(void* ctx, int* tracer_name_size, void* reference);
 typedef int (*get_tracer_name_func)(void* ctx, char* tracer_name, void* reference, int size);
@@ -89,7 +90,7 @@ typedef int (*get_tracer_partition_coefficient_func)(void* ctx, double* out, voi
 typedef int (*get_plugin_input_data_multiplereference_selected_size_func)(void* ctx, int* indexes_size, const char* plugin_id, const char* var_name);
 typedef int (*get_input_variable_func)(void* ctx, double* out, const char* var_name, int phase_id);
 typedef int (*get_ucm_fluid_geometrical_properties_func)(void* ctx, double* S_w, double* S_i, double* H, double alpha_G, double D);
-typedef int (*get_relative_emulsion_viscosity_func)(void* ctx, double* out, double mu_disp, double mu_cont, double alpha_disp_in_layer, int disp_field_id, int cont_field_id);
+typedef int (*get_relative_emulsion_viscosity_func)(void* ctx, double* out, double mu_disp, double mu_cont, double alpha_disp_in_layer, double T, bool water_in_oil);
 
 struct ALFAsimSDK_API {
 #if defined(_WIN32)
@@ -143,6 +144,8 @@ struct ALFAsimSDK_API {
     get_flow_pattern_func get_flow_pattern;
     get_flow_pattern_func get_liqliq_flow_pattern;
 
+    get_deposition_thickness_func get_deposition_thickness;
+
     get_tracer_id_func get_tracer_id;
     get_tracer_name_size_func get_tracer_name_size;
     get_tracer_name_func get_tracer_name;
